@@ -7,7 +7,9 @@
 #' @import anytime
 #' @import lubridate
 #' @import tibble
+#' @import stringi
 #' @importFrom stats setNames
+#' @importFrom methods is
 NULL
 
 BASE_PATH <- "https://api.clockify.me/api/v1"
@@ -15,6 +17,7 @@ REPORTS_BASE_PATH <- "https://reports.api.clockify.me/v1"
 
 globalVariables(
   c(
+    "%$%",
     ".",
     "address",
     "amount",
@@ -32,13 +35,17 @@ globalVariables(
     "error",
     "fields",
     "filters",
+    "fixed_date",
     "groupOne",
     "hourly_rate",
+    "is_public",
+    "link",
     "memberships",
     "name",
     "project_color",
     "project_id",
     "public",
+    "report_author",
     "start",
     "status",
     "template",
@@ -50,9 +57,12 @@ globalVariables(
     "time_end",
     "time_entry_id",
     "time_start",
+    "type",
     "user_id",
     "user_ids",
     "user_name",
+    "visible_to_users",
+    "visible_to_user_groups",
     "workspace_id",
     "workspaceId"
   )
