@@ -124,6 +124,9 @@ shared_reports <- function() {
   reports <- list()
 
   while (TRUE) {
+    log_debug("Get page ", query$page, " of shared reports.")
+    # Wait, otherwise get a 429 error (too many requests).
+    Sys.sleep((1))
     response <- GET(
       path,
       query = query
@@ -232,9 +235,7 @@ shared_report_update <- function(shared_report_id, name = NULL, is_public = NULL
   body <- list(
     name = name,
     isPublic = is_public,
-    fixedDate = fixed_date,
-    visibleToUsers = c(),
-    visibleToUserGroups = c()
+    fixedDate = fixed_date
   )
 
   response <- PUT(
